@@ -24,15 +24,15 @@
 #ifndef _KMESSAGEIO_H_
 #define _KMESSAGEIO_H_
 
-#include <QtCore/QObject>
-#include <QtCore/QProcess>
-#include <QtCore/QString>
-#include <QtNetwork/QHostAddress>
+#include <QObject>
+#include <QProcess>
+#include <QString>
+#include <QHostAddress>
 #include <QLoggingCategory>
 
 #include "../libkdegamesprivate_export.h"
 
-/* 
+/*
     This macro shouldn't be here ideally. Already declared in kgame.h, but throws error if not placed here.
 */
 Q_DECLARE_LOGGING_CATEGORY(GAMES_PRIVATE_KGAME)
@@ -43,7 +43,7 @@ class KProcess;
 
 /**
   \class KMessageIO kmessageio.h <KGame/KMessageIO>
-  
+
   This abstract base class represents one end of a message connections
   between two clients. Each client has one object of a subclass of
   KMessageIO. Calling /e send() on one object will emit the signal
@@ -85,7 +85,6 @@ public:
   //virtual bool isNetwork () const = 0;
   virtual bool isNetwork () const
   {
-   QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true"));  
    qCCritical(GAMES_PRIVATE_KGAME) << "Calling PURE virtual isNetwork...BAD";
    return false;
   }
@@ -100,7 +99,6 @@ public:
   //virtual bool isConnected () const = 0;
   virtual bool isConnected () const
   {
-   QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true"));  
    qCCritical(GAMES_PRIVATE_KGAME) << "Calling PURE virtual isConencted...BAD";
    return false;
   }
@@ -169,7 +167,7 @@ protected:
 
 /**
   \class KMessageSocket kmessageio.h <KGame/KMessageIO>
-  
+
   This class implements the message communication using a TCP/IP socket. The
   object can connect to a server socket, or can use an already connected socket.
 */
@@ -235,27 +233,27 @@ public:
   /**
   * The runtime idendifcation
   */
-  virtual int rtti() const {return 1;}
+  int rtti() const Q_DECL_OVERRIDE {return 1;}
 
   /**
     @return The port that this object is connected to. See QSocket::peerPort
   */
-  virtual quint16 peerPort () const;
+  quint16 peerPort () const Q_DECL_OVERRIDE;
 
   /**
     @return The hostname this object is connected to. See QSocket::peerName.
   */
-  virtual QString peerName () const;
+  QString peerName () const Q_DECL_OVERRIDE;
 
   /**
     @return TRUE as this is a network IO.
   */
-  bool isNetwork() const { return true; }
+  bool isNetwork() const Q_DECL_OVERRIDE { return true; }
 
   /**
     Returns true if the socket is in state /e connected.
   */
-  bool isConnected () const;
+  bool isConnected () const Q_DECL_OVERRIDE;
 
   /**
     Overwritten slot method from KMessageIO.
@@ -263,7 +261,7 @@ public:
     Note: It is not declared as a slot method, since the slot is already
     defined in KMessageIO as a virtual method.
   */
-  void send (const QByteArray &msg);
+  void send (const QByteArray &msg) Q_DECL_OVERRIDE;
 
 protected Q_SLOTS:
   virtual void processNewData ();
@@ -280,7 +278,7 @@ protected:
 
 /**
   \class KMessageDirect kmessageio.h <KGame/KMessageIO>
-  
+
   This class implements the message communication using function calls
   directly. It can only be used when both sides of the message pipe are
   within the same process. The communication is very fast.
@@ -320,13 +318,13 @@ public:
   /**
   * The runtime idendifcation
   */
-  virtual int rtti() const {return 2;}
+  int rtti() const Q_DECL_OVERRIDE {return 2;}
 
 
   /**
     @return FALSE as this is no network IO.
   */
-  bool isNetwork() const { return false; }
+  bool isNetwork() const Q_DECL_OVERRIDE { return false; }
 
   /**
     Returns true, if the object is connected to another instance.
@@ -336,7 +334,7 @@ public:
 
     The connection can only be closed by deleting one of the objects.
   */
-  bool isConnected () const;
+  bool isConnected () const Q_DECL_OVERRIDE;
 
   /**
     Overwritten slot method from KMessageIO.
@@ -344,7 +342,7 @@ public:
     Note: It is not declared as a slot method, since the slot is already
     defined in KMessageIO as a virtual method.
   */
-  void send (const QByteArray &msg);
+  void send (const QByteArray &msg) Q_DECL_OVERRIDE;
 
 protected:
   KMessageDirect *mPartner;
@@ -355,23 +353,23 @@ protected:
  */
 class KMessageProcess : public KMessageIO
 {
-  Q_OBJECT 
+  Q_OBJECT
 
   public:
     KMessageProcess(QObject *parent, const QString& file);
     ~KMessageProcess();
-    bool isConnected() const;
-    void send (const QByteArray &msg);
+    bool isConnected() const Q_DECL_OVERRIDE;
+    void send (const QByteArray &msg) Q_DECL_OVERRIDE;
 
     /**
       @return FALSE as this is no network IO.
     */
-    bool isNetwork() const { return false; }
+    bool isNetwork() const Q_DECL_OVERRIDE { return false; }
 
   /**
   * The runtime idendifcation
   */
-  virtual int rtti() const {return 3;}
+  int rtti() const Q_DECL_OVERRIDE {return 3;}
 
 
 
